@@ -1,3 +1,4 @@
+from datetime import datetime
 from enum import Enum
 
 from checkout_sdk.common.enums import AccountHolderIdentificationType, AccountHolderType, Country
@@ -33,6 +34,7 @@ class AccountHolderIdentification:
     type: AccountHolderIdentificationType
     number: str
     issuing_country: Country
+    date_of_expiry: str
 
 
 class AccountHolder:
@@ -49,6 +51,7 @@ class AccountHolder:
     identification: AccountHolderIdentification
     email: str
     gender: str
+    middle_name: str
 
 
 class BankDetails:
@@ -105,3 +108,8 @@ class ShippingInfo:
     return_shipping_company: str
     return_tracking_number: str
     return_tracking_uri: str
+
+
+class QueryFilterDateRange:
+    from_: datetime
+    to: datetime
